from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

CPU = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CDP1802ACE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDP1802ACE'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'CPU Processor', 'description':'', 'datasheet':'http://www.cosmacelf.com/publications/data-sheets/cdp1802.pdf', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nCDP1802ACE\n\nCPU Processor', 'pins':[
            Pin(num='1',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='BUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='BUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='BUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='BUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='BUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='N2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='N1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='N0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{WAIT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{EF4}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{EF3}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{EF2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{EF1}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='MA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='MA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='MA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='MA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CLEAR}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='MA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='MA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='TPB',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='TPA',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='~{MWR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{INTERRUPT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DMA_OUT}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{DMA_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{XTAL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{MRD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='BUS6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'P4080-BGA1295', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P4080-BGA1295'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Communications Processor', 'description':'', 'datasheet':'https://www.nxp.com/jp/products/microcontrollers-and-processors/power-architecture-processors/qoriq-platforms/p-series/qoriq-p4080-p4040-p4081-multicore-communications-processors:P4080?&tab=Documentation_Tab&linkline=Data-Sheet', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nP4080-BGA1295\n\nCommunications Processor', 'pins':[
            Pin(num='A14',name='D1_MDQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='D1_MDQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='D1_MDM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A17',name='D1_MDQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='/D1_MRAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='AA5',name='D1_MDIC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='D1_MA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='AA8',name='D1_MBA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='AB5',name='D1_MDQ36',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='D1_MDQ37',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='/D1_MWE',func=pin_types.OUTPUT,unit=1),
            Pin(num='AB9',name='/D1_MCS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='AC10',name='/D1_MCAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='AC6',name='D1_MDQ33',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='D1_MDQ32',func=pin_types.BIDIR,unit=1),
            Pin(num='AC9',name='/D1_MCS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='AD10',name='D1_MODT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='AD4',name='/D1_MDQS4',func=pin_types.BIDIR,unit=1),
            Pin(num='AD5',name='D1_MDQS4',func=pin_types.BIDIR,unit=1),
            Pin(num='AD7',name='D1_MDM4',func=pin_types.OUTPUT,unit=1),
            Pin(num='AD8',name='D1_MODT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='AE5',name='D1_MDQ38',func=pin_types.BIDIR,unit=1),
            Pin(num='AE6',name='D1_MDQ39',func=pin_types.BIDIR,unit=1),
            Pin(num='AE8',name='D1_MA13',func=pin_types.OUTPUT,unit=1),
            Pin(num='AE9',name='/D1_MCS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='AF10',name='D1_MODT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='AF6',name='D1_MDQ34',func=pin_types.BIDIR,unit=1),
            Pin(num='AF7',name='D1_MDQ35',func=pin_types.BIDIR,unit=1),
            Pin(num='AF9',name='/D1_MCS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='AG10',name='D1_MODT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='AG5',name='D1_MDQ40',func=pin_types.BIDIR,unit=1),
            Pin(num='AG7',name='D1_MDQ45',func=pin_types.BIDIR,unit=1),
            Pin(num='AG8',name='D1_MDQ44',func=pin_types.BIDIR,unit=1),
            Pin(num='AH5',name='/D1_MDQS5',func=pin_types.BIDIR,unit=1),
            Pin(num='AH6',name='D1_MDQS5',func=pin_types.BIDIR,unit=1),
            Pin(num='AH8',name='D1_MDM5',func=pin_types.OUTPUT,unit=1),
            Pin(num='AH9',name='D1_MDQ41',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ10',name='D1_MDQ43',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ6',name='D1_MDQ46',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ7',name='D1_MDQ47',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ9',name='D1_MDQ42',func=pin_types.BIDIR,unit=1),
            Pin(num='AK7',name='D1_MDQ53',func=pin_types.BIDIR,unit=1),
            Pin(num='AK8',name='D1_MDQ52',func=pin_types.BIDIR,unit=1),
            Pin(num='AL1',name='D1_MCK5',func=pin_types.OUTPUT,unit=1),
            Pin(num='AL11',name='D1_MDM6',func=pin_types.OUTPUT,unit=1),
            Pin(num='AL2',name='/D1_MCK5',func=pin_types.OUTPUT,unit=1),
            Pin(num='AL8',name='D1_MDQ49',func=pin_types.BIDIR,unit=1),
            Pin(num='AL9',name='D1_MDQ48',func=pin_types.BIDIR,unit=1),
            Pin(num='AM10',name='D1_MDQS6',func=pin_types.BIDIR,unit=1),
            Pin(num='AM9',name='/D1_MDQS6',func=pin_types.BIDIR,unit=1),
            Pin(num='AN10',name='D1_MDQ50',func=pin_types.BIDIR,unit=1),
            Pin(num='AN11',name='D1_MDQ51',func=pin_types.BIDIR,unit=1),
            Pin(num='AN7',name='D1_MDQ54',func=pin_types.BIDIR,unit=1),
            Pin(num='AN8',name='D1_MDQ55',func=pin_types.BIDIR,unit=1),
            Pin(num='AP12',name='D1_MDQ63',func=pin_types.BIDIR,unit=1),
            Pin(num='AP9',name='D1_MDQ60',func=pin_types.BIDIR,unit=1),
            Pin(num='AR10',name='D1_MDQ57',func=pin_types.BIDIR,unit=1),
            Pin(num='AR12',name='D1_MDQ62',func=pin_types.BIDIR,unit=1),
            Pin(num='AR13',name='D1_MDQ59',func=pin_types.BIDIR,unit=1),
            Pin(num='AR9',name='D1_MDQ61',func=pin_types.BIDIR,unit=1),
            Pin(num='AT10',name='D1_MDM7',func=pin_types.OUTPUT,unit=1),
            Pin(num='AT11',name='/D1_MDQS7',func=pin_types.BIDIR,unit=1),
            Pin(num='AT12',name='D1_MDQS7',func=pin_types.BIDIR,unit=1),
            Pin(num='AT13',name='D1_MDQ58',func=pin_types.BIDIR,unit=1),
            Pin(num='AT9',name='D1_MDQ56',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='D1_MDQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='/D1_MDQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='D1_MDQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='D1_MDQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='D1_MDQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='D1_MDQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='D1_MDQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='D1_MDQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='D1_MDQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='D1_MDM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D12',name='D1_MDQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='D1_MDM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='D15',name='D1_MDQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='D1_MDQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='/D1_MDQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='D1_MDQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='D1_MDQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='D1_MDQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='D1_MDQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='D1_MDQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='D1_MDQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='D1_MDQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='D1_MDQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='D1_MCK4',func=pin_types.OUTPUT,unit=1),
            Pin(num='F10',name='D1_MDQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='D1_MDQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='D1_MDQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='/D1_MDQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='D1_MDQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='/D1_MCK4',func=pin_types.OUTPUT,unit=1),
            Pin(num='F7',name='D1_MDQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='D1_MDQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='D1_MDM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='G12',name='D1_MDQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='D1_MDQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='D1_MDQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='/D1_MDQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='D1_MDQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='D1_MDQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='D1_MDQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='D1_MDQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='D1_MDQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='D1_MECC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='D1_MECC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='D1_MECC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='/D1_MDQS8',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='D1_MDQS8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='D1_MDM8',func=pin_types.OUTPUT,unit=1),
            Pin(num='K9',name='D1_MECC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='D1_MECC2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='D1_MA15',func=pin_types.OUTPUT,unit=1),
            Pin(num='L7',name='D1_MECC6',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='D1_MECC7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='D1_MECC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='D1_MA14',func=pin_types.OUTPUT,unit=1),
            Pin(num='M8',name='D1_MBA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='N6',name='D1_MA12',func=pin_types.OUTPUT,unit=1),
            Pin(num='N8',name='/D1_MAPAR_ERR',func=pin_types.INPUT,unit=1),
            Pin(num='N9',name='D1_MCKE3',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='D1_MCKE0',func=pin_types.OUTPUT,unit=1),
            Pin(num='P6',name='D1_MA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='P7',name='D1_MA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='P9',name='D1_MCKE2',func=pin_types.OUTPUT,unit=1),
            Pin(num='R10',name='D1_MCKE1',func=pin_types.OUTPUT,unit=1),
            Pin(num='R7',name='D1_MA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='R8',name='D1_MA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='T6',name='D1_MDIC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='D1_MA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='T9',name='D1_MA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='D1_MA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='U6',name='D1_MA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='U7',name='D1_MA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='U9',name='D1_MA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='V5',name='/D1_MCK1',func=pin_types.OUTPUT,unit=1),
            Pin(num='V6',name='D1_MCK1',func=pin_types.OUTPUT,unit=1),
            Pin(num='V8',name='D1_MCK2',func=pin_types.OUTPUT,unit=1),
            Pin(num='V9',name='/D1_MCK2',func=pin_types.OUTPUT,unit=1),
            Pin(num='W5',name='/D1_MCK0',func=pin_types.OUTPUT,unit=1),
            Pin(num='W6',name='D1_MCK0',func=pin_types.OUTPUT,unit=1),
            Pin(num='W8',name='/D1_MCK3',func=pin_types.OUTPUT,unit=1),
            Pin(num='W9',name='D1_MCK3',func=pin_types.OUTPUT,unit=1),
            Pin(num='Y10',name='D1_MBA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='Y7',name='D1_MAPAR_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='Y9',name='D1_MA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A10',name='D2_MDQS0',func=pin_types.BIDIR,unit=2),
            Pin(num='A11',name='/D2_MDQS0',func=pin_types.BIDIR,unit=2),
            Pin(num='A12',name='D2_MDQ1',func=pin_types.BIDIR,unit=2),
            Pin(num='A13',name='D2_MDQ4',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='D2_MDQ21',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='D2_MDQ20',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='D2_MDQ10',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='D2_MDQS1',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='/D2_MDQS1',func=pin_types.BIDIR,unit=2),
            Pin(num='A7',name='D2_MDQ8',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='D2_MDQ3',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='D2_MDQ7',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='D2_MBA1',func=pin_types.OUTPUT,unit=2),
            Pin(num='AA2',name='D2_MA10',func=pin_types.OUTPUT,unit=2),
            Pin(num='AA3',name='D2_MBA0',func=pin_types.OUTPUT,unit=2),
            Pin(num='AA4',name='D2_MDIC0',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='/D2_MRAS',func=pin_types.OUTPUT,unit=2),
            Pin(num='AB2',name='/D2_MWE',func=pin_types.OUTPUT,unit=2),
            Pin(num='AB3',name='/D2_MCS2',func=pin_types.OUTPUT,unit=2),
            Pin(num='AC1',name='/D2_MCS0',func=pin_types.OUTPUT,unit=2),
            Pin(num='AC3',name='/D2_MCAS',func=pin_types.OUTPUT,unit=2),
            Pin(num='AC4',name='D2_MA13',func=pin_types.OUTPUT,unit=2),
            Pin(num='AD1',name='D2_MODT2',func=pin_types.OUTPUT,unit=2),
            Pin(num='AD2',name='D2_MODT0',func=pin_types.OUTPUT,unit=2),
            Pin(num='AE1',name='/D2_MCS1',func=pin_types.OUTPUT,unit=2),
            Pin(num='AE2',name='/D2_MCS3',func=pin_types.OUTPUT,unit=2),
            Pin(num='AE3',name='D2_MODT3',func=pin_types.OUTPUT,unit=2),
            Pin(num='AF1',name='D2_MODT1',func=pin_types.OUTPUT,unit=2),
            Pin(num='AF3',name='D2_MDQ37',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='D2_MDQ36',func=pin_types.BIDIR,unit=2),
            Pin(num='AG1',name='D2_MDM4',func=pin_types.OUTPUT,unit=2),
            Pin(num='AG2',name='D2_MDQ33',func=pin_types.BIDIR,unit=2),
            Pin(num='AG4',name='D2_MDQ32',func=pin_types.BIDIR,unit=2),
            Pin(num='AH1',name='D2_MDQ38',func=pin_types.BIDIR,unit=2),
            Pin(num='AH2',name='D2_MDQS4',func=pin_types.BIDIR,unit=2),
            Pin(num='AH3',name='/D2_MDQS4',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ1',name='D2_MDQ35',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ3',name='D2_MDQ34',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ4',name='D2_MDQ39',func=pin_types.BIDIR,unit=2),
            Pin(num='AK1',name='/D2_MCK5',func=pin_types.OUTPUT,unit=2),
            Pin(num='AK2',name='D2_MCK5',func=pin_types.OUTPUT,unit=2),
            Pin(num='AK4',name='D2_MDQ45',func=pin_types.BIDIR,unit=2),
            Pin(num='AK5',name='D2_MDQ44',func=pin_types.BIDIR,unit=2),
            Pin(num='AL3',name='D2_MDM5',func=pin_types.OUTPUT,unit=2),
            Pin(num='AL5',name='D2_MDQ41',func=pin_types.BIDIR,unit=2),
            Pin(num='AL6',name='D2_MDQ40',func=pin_types.BIDIR,unit=2),
            Pin(num='AM1',name='D2_MDQ52',func=pin_types.BIDIR,unit=2),
            Pin(num='AM3',name='/D2_MDQS5',func=pin_types.BIDIR,unit=2),
            Pin(num='AM4',name='D2_MDQS5',func=pin_types.BIDIR,unit=2),
            Pin(num='AM6',name='D2_MDQ46',func=pin_types.BIDIR,unit=2),
            Pin(num='AM7',name='D2_MDQ47',func=pin_types.BIDIR,unit=2),
            Pin(num='AN1',name='D2_MDQ48',func=pin_types.BIDIR,unit=2),
            Pin(num='AN2',name='D2_MDQ53',func=pin_types.BIDIR,unit=2),
            Pin(num='AN4',name='D2_MDQ42',func=pin_types.BIDIR,unit=2),
            Pin(num='AN5',name='D2_MDQ43',func=pin_types.BIDIR,unit=2),
            Pin(num='AP1',name='/D2_MDQS6',func=pin_types.BIDIR,unit=2),
            Pin(num='AP2',name='D2_MDM6',func=pin_types.OUTPUT,unit=2),
            Pin(num='AP3',name='D2_MDQ49',func=pin_types.BIDIR,unit=2),
            Pin(num='AP5',name='D2_MDQ56',func=pin_types.BIDIR,unit=2),
            Pin(num='AP6',name='D2_MDM7',func=pin_types.OUTPUT,unit=2),
            Pin(num='AP8',name='D2_MDQ58',func=pin_types.BIDIR,unit=2),
            Pin(num='AR1',name='D2_MDQS6',func=pin_types.BIDIR,unit=2),
            Pin(num='AR3',name='D2_MDQ54',func=pin_types.BIDIR,unit=2),
            Pin(num='AR4',name='D2_MDQ60',func=pin_types.BIDIR,unit=2),
            Pin(num='AR6',name='D2_MDQS7',func=pin_types.BIDIR,unit=2),
            Pin(num='AR7',name='D2_MDQ62',func=pin_types.BIDIR,unit=2),
            Pin(num='AT1',name='D2_MDQ50',func=pin_types.BIDIR,unit=2),
            Pin(num='AT2',name='D2_MDQ51',func=pin_types.BIDIR,unit=2),
            Pin(num='AT3',name='D2_MDQ55',func=pin_types.BIDIR,unit=2),
            Pin(num='AT4',name='D2_MDQ61',func=pin_types.BIDIR,unit=2),
            Pin(num='AT5',name='D2_MDQ57',func=pin_types.BIDIR,unit=2),
            Pin(num='AT6',name='/D2_MDQS7',func=pin_types.BIDIR,unit=2),
            Pin(num='AT7',name='D2_MDQ63',func=pin_types.BIDIR,unit=2),
            Pin(num='AT8',name='D2_MDQ59',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='D2_MDQ16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='D2_MDQ6',func=pin_types.BIDIR,unit=2),
            Pin(num='B12',name='D2_MDM0',func=pin_types.OUTPUT,unit=2),
            Pin(num='B13',name='D2_MDQ5',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='D2_MDQ17',func=pin_types.BIDIR,unit=2),
            Pin(num='B4',name='D2_MDQ11',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='D2_MDM1',func=pin_types.OUTPUT,unit=2),
            Pin(num='B7',name='D2_MDQ13',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='D2_MDQ2',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='/D2_MDQS2',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='D2_MDQ0',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='D2_MDQS2',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='D2_MDM2',func=pin_types.OUTPUT,unit=2),
            Pin(num='C5',name='D2_MDQ14',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='D2_MDQ12',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='D2_MDQ22',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='D2_MDQ23',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='D2_MDQ18',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='D2_MDQ15',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='D2_MDQ9',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='D2_MDQ19',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='D2_MDQ29',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='D2_MDQ28',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='D2_MDQ24',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='D2_MDQ25',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='D2_MCK4',func=pin_types.OUTPUT,unit=2),
            Pin(num='G2',name='/D2_MCK4',func=pin_types.OUTPUT,unit=2),
            Pin(num='G3',name='D2_MDM3',func=pin_types.OUTPUT,unit=2),
            Pin(num='G5',name='/D2_MDQS3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='D2_MDQS3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='D2_MDQ31',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='D2_MDQ30',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='D2_MDQ26',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='D2_MDQ27',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='D2_MECC0',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='D2_MECC5',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='D2_MECC4',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='/D2_MDQS8',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='D2_MDM8',func=pin_types.OUTPUT,unit=2),
            Pin(num='K3',name='D2_MECC1',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='D2_MDQS8',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='D2_MECC6',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='D2_MECC7',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='D2_MBA2',func=pin_types.OUTPUT,unit=2),
            Pin(num='M2',name='D2_MA15',func=pin_types.OUTPUT,unit=2),
            Pin(num='M4',name='D2_MCKE3',func=pin_types.OUTPUT,unit=2),
            Pin(num='M5',name='D2_MECC2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='D2_MA12',func=pin_types.OUTPUT,unit=2),
            Pin(num='N2',name='/D2_MAPA_ERR',func=pin_types.INPUT,unit=2),
            Pin(num='N3',name='D2_MA14',func=pin_types.OUTPUT,unit=2),
            Pin(num='N5',name='D2_MECC3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='D2_MA9',func=pin_types.OUTPUT,unit=2),
            Pin(num='P3',name='D2_MA11',func=pin_types.OUTPUT,unit=2),
            Pin(num='P4',name='D2_MCKE2',func=pin_types.OUTPUT,unit=2),
            Pin(num='R1',name='D2_MA6',func=pin_types.OUTPUT,unit=2),
            Pin(num='R2',name='D2_MA8',func=pin_types.OUTPUT,unit=2),
            Pin(num='R4',name='D2_MA7',func=pin_types.OUTPUT,unit=2),
            Pin(num='R5',name='D2_MCKE0',func=pin_types.OUTPUT,unit=2),
            Pin(num='T1',name='D2_MA3',func=pin_types.OUTPUT,unit=2),
            Pin(num='T2',name='D2_MA4',func=pin_types.OUTPUT,unit=2),
            Pin(num='T3',name='D2_MA5',func=pin_types.OUTPUT,unit=2),
            Pin(num='T5',name='D2_MCKE1',func=pin_types.OUTPUT,unit=2),
            Pin(num='U1',name='D2_MA1',func=pin_types.OUTPUT,unit=2),
            Pin(num='U4',name='D2_MA2',func=pin_types.OUTPUT,unit=2),
            Pin(num='V1',name='D2_MCK2',func=pin_types.OUTPUT,unit=2),
            Pin(num='V2',name='/D2_MCK2',func=pin_types.OUTPUT,unit=2),
            Pin(num='V3',name='D2_MCK1',func=pin_types.OUTPUT,unit=2),
            Pin(num='V4',name='/D2_MCK1',func=pin_types.OUTPUT,unit=2),
            Pin(num='W1',name='/D2_MCK3',func=pin_types.OUTPUT,unit=2),
            Pin(num='W2',name='D2_MCK3',func=pin_types.OUTPUT,unit=2),
            Pin(num='W3',name='D2_MCK0',func=pin_types.OUTPUT,unit=2),
            Pin(num='W4',name='/D2_MCK0',func=pin_types.OUTPUT,unit=2),
            Pin(num='Y1',name='D2_MAPAR_OUT',func=pin_types.OUTPUT,unit=2),
            Pin(num='Y4',name='D2_MA0',func=pin_types.OUTPUT,unit=2),
            Pin(num='Y6',name='D2_MDIC1',func=pin_types.BIDIR,unit=2),
            Pin(num='A23',name='LALE',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='/LWE1',func=pin_types.OUTPUT,unit=3),
            Pin(num='AG13',name='IRQ8/GPIO26',func=pin_types.INPUT,unit=3),
            Pin(num='AG17',name='IRQ6/GPIO24',func=pin_types.INPUT,unit=3),
            Pin(num='AG19',name='/DMA2_DACK0',func=pin_types.OUTPUT,unit=3),
            Pin(num='AG20',name='GPIO7',func=pin_types.BIDIR,unit=3),
            Pin(num='AH14',name='GPIO28/IRQ10',func=pin_types.BIDIR,unit=3),
            Pin(num='AH16',name='IRQ1',func=pin_types.INPUT,unit=3),
            Pin(num='AH17',name='IRQ4/GPIO22',func=pin_types.INPUT,unit=3),
            Pin(num='AH21',name='GPIO4',func=pin_types.BIDIR,unit=3),
            Pin(num='AH23',name='GPIO15/CTS/UART4_SIN',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ13',name='IRQ5/GPIO23',func=pin_types.INPUT,unit=3),
            Pin(num='AJ15',name='IRQ3/GPIO21',func=pin_types.INPUT,unit=3),
            Pin(num='AJ16',name='IRQ0',func=pin_types.INPUT,unit=3),
            Pin(num='AJ20',name='GPIO20/DMA2_DREQ0/ALT_MDVAL',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ21',name='GPIO5',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ22',name='GPIO9/UART2_SOUT',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ34',name='GPIO31/TSEC_1588_PULSE_OUT2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK11',name='IRQ9/GPIO27',func=pin_types.INPUT,unit=3),
            Pin(num='AK12',name='IRQ2',func=pin_types.INPUT,unit=3),
            Pin(num='AK13',name='GPIO16/IIC3_SCL/SDHC_CD',func=pin_types.BIDIR,unit=3),
            Pin(num='AK14',name='/IRQ_OUT/EVT9',func=pin_types.OUTPUT,unit=3),
            Pin(num='AK21',name='GPIO6',func=pin_types.BIDIR,unit=3),
            Pin(num='AK22',name='GPIO1',func=pin_types.BIDIR,unit=3),
            Pin(num='AK23',name='GPIO13/RTS/UART4_SOUT',func=pin_types.BIDIR,unit=3),
            Pin(num='AK35',name='GPIO30/TSEC_1588_ALARM_OUT2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL12',name='IRQ11/GPIO29',func=pin_types.INPUT,unit=3),
            Pin(num='AL19',name='GPIO19/DMA1_DACK0',func=pin_types.BIDIR,unit=3),
            Pin(num='AL21',name='GPIO0',func=pin_types.BIDIR,unit=3),
            Pin(num='AL22',name='GPIO8/UART1_SOUT',func=pin_types.BIDIR,unit=3),
            Pin(num='AM13',name='IRQ7/GPIO25',func=pin_types.INPUT,unit=3),
            Pin(num='AM14',name='GPIO17/IIC3_SDA/SDHC_WP',func=pin_types.BIDIR,unit=3),
            Pin(num='AM20',name='GPIO2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM22',name='GPIO12/RTS/UART3_SOUT',func=pin_types.BIDIR,unit=3),
            Pin(num='AN19',name='/TMP_DETECT',func=pin_types.INPUT,unit=3),
            Pin(num='AN20',name='GPIO3',func=pin_types.BIDIR,unit=3),
            Pin(num='AN21',name='/DMA1_DDONE0',func=pin_types.OUTPUT,unit=3),
            Pin(num='AN23',name='GPIO11/UART2_SIN',func=pin_types.BIDIR,unit=3),
            Pin(num='AP20',name='/DMA2_DDONE0',func=pin_types.OUTPUT,unit=3),
            Pin(num='AP21',name='GPIO18/DMA1_DREQ0',func=pin_types.BIDIR,unit=3),
            Pin(num='AP22',name='GPIO14/CTS/UART3_SIN',func=pin_types.BIDIR,unit=3),
            Pin(num='AR23',name='GPIO10/UART1_SIN',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='/LCS5',func=pin_types.OUTPUT,unit=3),
            Pin(num='B25',name='LGPL0',func=pin_types.OUTPUT,unit=3),
            Pin(num='C22',name='LBCTL',func=pin_types.OUTPUT,unit=3),
            Pin(num='C23',name='LCLK1',func=pin_types.OUTPUT,unit=3),
            Pin(num='C24',name='LCLK0',func=pin_types.OUTPUT,unit=3),
            Pin(num='C25',name='LGPL4',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='/LCS0',func=pin_types.OUTPUT,unit=3),
            Pin(num='D20',name='/LCS1',func=pin_types.OUTPUT,unit=3),
            Pin(num='D21',name='/LCS3',func=pin_types.OUTPUT,unit=3),
            Pin(num='D22',name='/LCS4',func=pin_types.OUTPUT,unit=3),
            Pin(num='D23',name='LAD9',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='/LWE0',func=pin_types.OUTPUT,unit=3),
            Pin(num='D25',name='LGPL2',func=pin_types.OUTPUT,unit=3),
            Pin(num='E20',name='/LCS2',func=pin_types.OUTPUT,unit=3),
            Pin(num='E21',name='LA21',func=pin_types.OUTPUT,unit=3),
            Pin(num='E23',name='LAD8',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='LGPL1',func=pin_types.OUTPUT,unit=3),
            Pin(num='E26',name='LGPL5',func=pin_types.OUTPUT,unit=3),
            Pin(num='F19',name='LAD12',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='LA22',func=pin_types.OUTPUT,unit=3),
            Pin(num='F22',name='LA19',func=pin_types.OUTPUT,unit=3),
            Pin(num='F24',name='/LCS6',func=pin_types.OUTPUT,unit=3),
            Pin(num='F25',name='LAD4',func=pin_types.BIDIR,unit=3),
            Pin(num='G18',name='LA31',func=pin_types.OUTPUT,unit=3),
            Pin(num='G19',name='LA28',func=pin_types.OUTPUT,unit=3),
            Pin(num='G20',name='LA25',func=pin_types.OUTPUT,unit=3),
            Pin(num='G22',name='LAD11',func=pin_types.BIDIR,unit=3),
            Pin(num='G23',name='LAD7',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='LAD6',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='LA17',func=pin_types.OUTPUT,unit=3),
            Pin(num='G26',name='/LCS7',func=pin_types.OUTPUT,unit=3),
            Pin(num='H19',name='LA29',func=pin_types.OUTPUT,unit=3),
            Pin(num='H21',name='LA23',func=pin_types.OUTPUT,unit=3),
            Pin(num='H22',name='LA20',func=pin_types.OUTPUT,unit=3),
            Pin(num='H23',name='LA18',func=pin_types.OUTPUT,unit=3),
            Pin(num='H24',name='LAD5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='LAD3',func=pin_types.BIDIR,unit=3),
            Pin(num='H26',name='LGPL3',func=pin_types.OUTPUT,unit=3),
            Pin(num='J17',name='LAD15',func=pin_types.BIDIR,unit=3),
            Pin(num='J18',name='LAD13',func=pin_types.BIDIR,unit=3),
            Pin(num='J19',name='LA30',func=pin_types.OUTPUT,unit=3),
            Pin(num='J20',name='LA26',func=pin_types.OUTPUT,unit=3),
            Pin(num='J22',name='LAD10',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='LDP0',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='LA16',func=pin_types.OUTPUT,unit=3),
            Pin(num='J26',name='LAD2',func=pin_types.BIDIR,unit=3),
            Pin(num='K18',name='LAD14',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='LA27',func=pin_types.OUTPUT,unit=3),
            Pin(num='K21',name='LA24',func=pin_types.OUTPUT,unit=3),
            Pin(num='K23',name='LDP1',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='LAD0',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='LAD1',func=pin_types.BIDIR,unit=3),
            Pin(num='A29',name='SD_RX1',func=pin_types.INPUT,unit=4),
            Pin(num='A31',name='SD_RX3',func=pin_types.INPUT,unit=4),
            Pin(num='A35',name='SD_REF_CLK1',func=pin_types.INPUT,unit=4),
            Pin(num='AA31',name='SD_TX14',func=pin_types.OUTPUT,unit=4),
            Pin(num='AA32',name='/SD_TX14',func=pin_types.OUTPUT,unit=4),
            Pin(num='AA35',name='/SD_RX14',func=pin_types.INPUT,unit=4),
            Pin(num='AA36',name='SD_RX14',func=pin_types.INPUT,unit=4),
            Pin(num='AB33',name='SD_TX15',func=pin_types.OUTPUT,unit=4),
            Pin(num='AB34',name='/SD_TX15',func=pin_types.OUTPUT,unit=4),
            Pin(num='AC31',name='/SD_REF_CLK3',func=pin_types.INPUT,unit=4),
            Pin(num='AC32',name='SD_REF_CLK3',func=pin_types.INPUT,unit=4),
            Pin(num='AC35',name='/SD_RX15',func=pin_types.INPUT,unit=4),
            Pin(num='AC36',name='SD_RX15',func=pin_types.INPUT,unit=4),
            Pin(num='AE31',name='SD_TX16',func=pin_types.OUTPUT,unit=4),
            Pin(num='AE32',name='/SD_TX16',func=pin_types.OUTPUT,unit=4),
            Pin(num='AF33',name='/SD_RX16',func=pin_types.INPUT,unit=4),
            Pin(num='AF34',name='SD_RX16',func=pin_types.INPUT,unit=4),
            Pin(num='AG31',name='SD_TX17',func=pin_types.OUTPUT,unit=4),
            Pin(num='AG32',name='/SD_TX17',func=pin_types.OUTPUT,unit=4),
            Pin(num='AG35',name='/SD_RX17',func=pin_types.INPUT,unit=4),
            Pin(num='AG36',name='SD_RX17',func=pin_types.INPUT,unit=4),
            Pin(num='B29',name='/SD_RX1',func=pin_types.INPUT,unit=4),
            Pin(num='B31',name='/SD_RX3',func=pin_types.INPUT,unit=4),
            Pin(num='B35',name='/SD_REF_CLK1',func=pin_types.INPUT,unit=4),
            Pin(num='C28',name='SD_RX0',func=pin_types.INPUT,unit=4),
            Pin(num='C30',name='SD_RX2',func=pin_types.INPUT,unit=4),
            Pin(num='C36',name='/SD_RX4',func=pin_types.INPUT,unit=4),
            Pin(num='D28',name='/SD_RX0',func=pin_types.INPUT,unit=4),
            Pin(num='D30',name='/SD_RX2',func=pin_types.INPUT,unit=4),
            Pin(num='D34',name='SD_TX4',func=pin_types.OUTPUT,unit=4),
            Pin(num='D36',name='SD_RX4',func=pin_types.INPUT,unit=4),
            Pin(num='E29',name='/SD_TX1',func=pin_types.OUTPUT,unit=4),
            Pin(num='E31',name='/SD_TX3',func=pin_types.OUTPUT,unit=4),
            Pin(num='E34',name='/SD_TX4',func=pin_types.OUTPUT,unit=4),
            Pin(num='F29',name='SD_TX1',func=pin_types.OUTPUT,unit=4),
            Pin(num='F31',name='SD_TX3',func=pin_types.OUTPUT,unit=4),
            Pin(num='F33',name='/SD_TX5',func=pin_types.OUTPUT,unit=4),
            Pin(num='F35',name='/SD_RX5',func=pin_types.INPUT,unit=4),
            Pin(num='F36',name='SD_RX5',func=pin_types.INPUT,unit=4),
            Pin(num='G28',name='/SD_TX0',func=pin_types.OUTPUT,unit=4),
            Pin(num='G30',name='/SD_TX2',func=pin_types.OUTPUT,unit=4),
            Pin(num='G33',name='SD_TX5',func=pin_types.OUTPUT,unit=4),
            Pin(num='H28',name='SD_TX0',func=pin_types.OUTPUT,unit=4),
            Pin(num='H30',name='SD_TX2',func=pin_types.OUTPUT,unit=4),
            Pin(num='H35',name='/SD_RX6',func=pin_types.INPUT,unit=4),
            Pin(num='H36',name='SD_RX6',func=pin_types.INPUT,unit=4),
            Pin(num='J33',name='SD_TX6',func=pin_types.OUTPUT,unit=4),
            Pin(num='J34',name='/SD_TX6',func=pin_types.OUTPUT,unit=4),
            Pin(num='K31',name='SD_TX7',func=pin_types.OUTPUT,unit=4),
            Pin(num='K32',name='/SD_TX7',func=pin_types.OUTPUT,unit=4),
            Pin(num='K35',name='/SD_RX7',func=pin_types.INPUT,unit=4),
            Pin(num='K36',name='SD_RX7',func=pin_types.INPUT,unit=4),
            Pin(num='L33',name='/SD_RX8',func=pin_types.INPUT,unit=4),
            Pin(num='L34',name='SD_RX8',func=pin_types.INPUT,unit=4),
            Pin(num='M31',name='SD_TX8',func=pin_types.OUTPUT,unit=4),
            Pin(num='M32',name='/SD_TX8',func=pin_types.OUTPUT,unit=4),
            Pin(num='M35',name='/SD_RX9',func=pin_types.INPUT,unit=4),
            Pin(num='M36',name='SD_RX9',func=pin_types.INPUT,unit=4),
            Pin(num='N33',name='SD_TX9',func=pin_types.OUTPUT,unit=4),
            Pin(num='N34',name='/SD_TX9',func=pin_types.OUTPUT,unit=4),
            Pin(num='P31',name='SD_TX10',func=pin_types.OUTPUT,unit=4),
            Pin(num='P32',name='/SD_TX10',func=pin_types.OUTPUT,unit=4),
            Pin(num='P35',name='/SD_RX10',func=pin_types.INPUT,unit=4),
            Pin(num='P36',name='SD_RX10',func=pin_types.INPUT,unit=4),
            Pin(num='T30',name='SD_TX11',func=pin_types.OUTPUT,unit=4),
            Pin(num='T31',name='/SD_TX11',func=pin_types.OUTPUT,unit=4),
            Pin(num='T33',name='/SD_RX11',func=pin_types.INPUT,unit=4),
            Pin(num='T34',name='SD_RX11',func=pin_types.INPUT,unit=4),
            Pin(num='V33',name='/SD_REF_CLK2',func=pin_types.INPUT,unit=4),
            Pin(num='V34',name='SD_REF_CLK2',func=pin_types.INPUT,unit=4),
            Pin(num='W31',name='SD_TX12',func=pin_types.OUTPUT,unit=4),
            Pin(num='W32',name='/SD_TX12',func=pin_types.OUTPUT,unit=4),
            Pin(num='W35',name='/SD_RX12',func=pin_types.INPUT,unit=4),
            Pin(num='W36',name='SD_RX12',func=pin_types.INPUT,unit=4),
            Pin(num='Y29',name='SD_TX13',func=pin_types.OUTPUT,unit=4),
            Pin(num='Y30',name='/SD_TX13',func=pin_types.OUTPUT,unit=4),
            Pin(num='Y33',name='/SD_RX13',func=pin_types.INPUT,unit=4),
            Pin(num='Y34',name='SD_RX13',func=pin_types.INPUT,unit=4),
            Pin(num='A28',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='A30',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='A32',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='A33',name='AVDD_SRDS1',func=pin_types.PWRIN,unit=5),
            Pin(num='A34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='A36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA29',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AA30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA33',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AA34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AB31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AB32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AB36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AC30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AC33',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AC34',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AD30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AD31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AD32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AD35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AD36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AE30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AE33',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AE34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE35',name='AVDD_SRDS3',func=pin_types.PWRIN,unit=5),
            Pin(num='AE36',name='AGND_SRDS3',func=pin_types.PWRIN,unit=5),
            Pin(num='AF30',name='SD_IMP_CAL_TX',func=pin_types.INPUT,unit=5),
            Pin(num='AF31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AF32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AF36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AG30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AG33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AG34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AH31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AH32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AH33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AH35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='AH36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='B27',name='SD_IMP_CAL_RX',func=pin_types.INPUT,unit=5),
            Pin(num='B28',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='B30',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='B32',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='B33',name='AGND_SRDS1',func=pin_types.PWRIN,unit=5),
            Pin(num='B34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='B36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='C29',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='C31',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='C33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='C34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='C35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='D29',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='D31',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='D33',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='D35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='E28',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='E30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='E32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='E33',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='E35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='E36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='F28',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='F30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='F32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='F34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='G29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='G31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='G32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='G34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='G35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='G36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='H29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='H31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='H32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='H33',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='H34',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='J28',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='J29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='J30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='J31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='J32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='J35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='J36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='K28',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='K29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='K30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='K33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='K34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='L29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='L30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='L31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='L32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='L35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='L36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='M29',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='M30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='M33',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='M34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='N29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='N30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='N31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='N32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='N35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='N36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='P29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='P30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='P33',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='P34',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='R29',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='R30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='R31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='R32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='R33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='R34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='R35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='R36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='T29',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='T32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='T35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='T36',name='AGND_SRDS2',func=pin_types.PWRIN,unit=5),
            Pin(num='U29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='U30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='U31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='U33',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='U34',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='U36',name='AVDD_SRDS2',func=pin_types.PWRIN,unit=5),
            Pin(num='V29',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='V30',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='V31',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='V32',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='V35',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='V36',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='W29',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='W30',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='W33',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='W34',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='Y31',name='XVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='Y32',name='XGND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y35',name='SGND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y36',name='SVDD',func=pin_types.PWRIN,unit=5),
            Pin(num='AG14',name='IIC4_SCL/EVT5',func=pin_types.BIDIR,unit=6),
            Pin(num='AG19',name='ALT_MSRCID0/DMA2_DACK0/EVT7',func=pin_types.OUTPUT,unit=6),
            Pin(num='AG22',name='SDHC_DAT3',func=pin_types.BIDIR,unit=6),
            Pin(num='AG23',name='SDHC_CMD',func=pin_types.BIDIR,unit=6),
            Pin(num='AH15',name='IIC1_SCL',func=pin_types.BIDIR,unit=6),
            Pin(num='AH18',name='MSRCID2',func=pin_types.OUTPUT,unit=6),
            Pin(num='AH19',name='IO_VSEL4',func=pin_types.INPUT,unit=6),
            Pin(num='AH20',name='MSRCID0',func=pin_types.OUTPUT,unit=6),
            Pin(num='AH23',name='UART2_CTS/UART4_SIN/GPIO15',func=pin_types.INPUT,unit=6),
            Pin(num='AH28',name='SPI_MISO',func=pin_types.INPUT,unit=6),
            Pin(num='AJ17',name='/EVT0',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ19',name='MSRCID1',func=pin_types.OUTPUT,unit=6),
            Pin(num='AJ20',name='ALT_MDVAL/DMA2_DREQ0/GPIO20',func=pin_types.OUTPUT,unit=6),
            Pin(num='AJ22',name='UART2_SDOUT/GPIO9',func=pin_types.OUTPUT,unit=6),
            Pin(num='AJ28',name='SDHC_DAT5/SPI_CS1',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='TSEC_1588_PULSE_OUT2/GPIO31',func=pin_types.OUTPUT,unit=6),
            Pin(num='AJ36',name='TSEC_1588_ALARM_OUT1',func=pin_types.OUTPUT,unit=6),
            Pin(num='AK13',name='IIC3_SCL/GPIO16/SDHC_CD',func=pin_types.BIDIR,unit=6),
            Pin(num='AK14',name='/EVT9/IRQ_OUT',func=pin_types.BIDIR,unit=6),
            Pin(num='AK16',name='/EVT3',func=pin_types.BIDIR,unit=6),
            Pin(num='AK17',name='/EVT1',func=pin_types.BIDIR,unit=6),
            Pin(num='AK18',name='IO_VSEL2',func=pin_types.INPUT,unit=6),
            Pin(num='AK20',name='CLK_OUT',func=pin_types.OUTPUT,unit=6),
            Pin(num='AK23',name='UART2_RTS/UART4_SDOUT/GPIO13',func=pin_types.OUTPUT,unit=6),
            Pin(num='AK29',name='SPI_CLK',func=pin_types.OUTPUT,unit=6),
            Pin(num='AK35',name='TSEC_1588_ALARM_OUT2/GPIO30',func=pin_types.OUTPUT,unit=6),
            Pin(num='AK36',name='TSEC_1588_TRIG_IN2',func=pin_types.INPUT,unit=6),
            Pin(num='AL14',name='INC2_SDA',func=pin_types.BIDIR,unit=6),
            Pin(num='AL15',name='IIC4_SDA/EVT6',func=pin_types.BIDIR,unit=6),
            Pin(num='AL17',name='/SCAN_MODE',func=pin_types.INPUT,unit=6),
            Pin(num='AL18',name='IO_VSEL0',func=pin_types.INPUT,unit=6),
            Pin(num='AL22',name='UART1_SDOUT/GPIO8',func=pin_types.OUTPUT,unit=6),
            Pin(num='AL23',name='SDHC_CLK',func=pin_types.OUTPUT,unit=6),
            Pin(num='AL30',name='TSEC_1588_PULSE_OUT1',func=pin_types.OUTPUT,unit=6),
            Pin(num='AL35',name='TSEC_1588_CLK_IN',func=pin_types.INPUT,unit=6),
            Pin(num='AL36',name='TSEC_1588_TRIG_IN1C',func=pin_types.INPUT,unit=6),
            Pin(num='AM14',name='IIC3_SDA/GPIO17/SDHC_WP',func=pin_types.BIDIR,unit=6),
            Pin(num='AM15',name='INC2_SCL',func=pin_types.BIDIR,unit=6),
            Pin(num='AM16',name='/EVT4',func=pin_types.BIDIR,unit=6),
            Pin(num='AM18',name='IO_VSEL3',func=pin_types.INPUT,unit=6),
            Pin(num='AM19',name='/CKSTP_OUT',func=pin_types.OUTPUT,unit=6),
            Pin(num='AM22',name='UART1_RTS/UART3_SDOUT/GPIO12',func=pin_types.OUTPUT,unit=6),
            Pin(num='AM23',name='SDHC_DAT2',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='SDHC_DAT7/SPI_CS3',func=pin_types.BIDIR,unit=6),
            Pin(num='AM30',name='TSEC_1588_CLK_OUT',func=pin_types.OUTPUT,unit=6),
            Pin(num='AM33',name='USB1_D3/EC1_RXD3',func=pin_types.BIDIR,unit=6),
            Pin(num='AM34',name='USB1_NXT/EC1_RX_DV',func=pin_types.INPUT,unit=6),
            Pin(num='AM36',name='USB1_DIR/EC1_RX_CLK',func=pin_types.INPUT,unit=6),
            Pin(num='AN14',name='IIC1_SDA',func=pin_types.BIDIR,unit=6),
            Pin(num='AN16',name='/EVT2',func=pin_types.BIDIR,unit=6),
            Pin(num='AN17',name='TDI',func=pin_types.INPUT,unit=6),
            Pin(num='AN23',name='UART2_SIN/GPIO11',func=pin_types.INPUT,unit=6),
            Pin(num='AN24',name='RTC',func=pin_types.INPUT,unit=6),
            Pin(num='AN29',name='SDHC_DAT4/SPI_CS0',func=pin_types.BIDIR,unit=6),
            Pin(num='AN31',name='USB2_CLK/EC2_GTX_CLK',func=pin_types.INPUT,unit=6),
            Pin(num='AN32',name='USB2_D2/EC2_RXD2',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='USB1_D2/EC1_RXD2',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='USB1_D0/EC1_RXD1',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='USB1_D0/EC1_RXD0',func=pin_types.BIDIR,unit=6),
            Pin(num='AP15',name='TDO',func=pin_types.OUTPUT,unit=6),
            Pin(num='AP17',name='/PORESET',func=pin_types.INPUT,unit=6),
            Pin(num='AP18',name='IO_VSEL1',func=pin_types.INPUT,unit=6),
            Pin(num='AP20',name='ALT_MSRCID1/DMA2_DDONE0/EVT8',func=pin_types.OUTPUT,unit=6),
            Pin(num='AP22',name='UART1_CTS/UART3_SIN/GPIO14',func=pin_types.INPUT,unit=6),
            Pin(num='AP24',name='SDHC_DAT0',func=pin_types.BIDIR,unit=6),
            Pin(num='AP30',name='USB2_D6/EC2_TXD2',func=pin_types.BIDIR,unit=6),
            Pin(num='AP32',name='USB2_D1/EC2_RXD1',func=pin_types.BIDIR,unit=6),
            Pin(num='AP33',name='USB2_D3/EC2_RXD3',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='USB1_CLK/EC1_GTX_CLK',func=pin_types.INPUT,unit=6),
            Pin(num='AP36',name='USB1_D7/EC1_TXD3',func=pin_types.BIDIR,unit=6),
            Pin(num='AR15',name='MDVA',func=pin_types.OUTPUT,unit=6),
            Pin(num='AR17',name='/HRESET',func=pin_types.BIDIR,unit=6),
            Pin(num='AR19',name='/TRST',func=pin_types.INPUT,unit=6),
            Pin(num='AR20',name='TMS',func=pin_types.INPUT,unit=6),
            Pin(num='AR21',name='ASLEEP',func=pin_types.OUTPUT,unit=6),
            Pin(num='AR22',name='TCK',func=pin_types.INPUT,unit=6),
            Pin(num='AR23',name='UART1_SIN/GPIO10',func=pin_types.INPUT,unit=6),
            Pin(num='AR29',name='SDHC_DAT6/SPI_CS2',func=pin_types.BIDIR,unit=6),
            Pin(num='AR30',name='USB2_D5/EC2_TXD1',func=pin_types.BIDIR,unit=6),
            Pin(num='AR31',name='USB2_STP/EC2_TX_EN',func=pin_types.OUTPUT,unit=6),
            Pin(num='AR33',name='USB2_NXT/EC2_RX_DV',func=pin_types.INPUT,unit=6),
            Pin(num='AR34',name='USB1_D5/EC1_TXD1',func=pin_types.BIDIR,unit=6),
            Pin(num='AR36',name='USB1_STP/EC1_TX_EN',func=pin_types.OUTPUT,unit=6),
            Pin(num='AT16',name='/RESET_REQ',func=pin_types.OUTPUT,unit=6),
            Pin(num='AT21',name='/TEST_SEL',func=pin_types.INPUT,unit=6),
            Pin(num='AT23',name='SYSCLK',func=pin_types.INPUT,unit=6),
            Pin(num='AT24',name='SDHC_DAT1',func=pin_types.BIDIR,unit=6),
            Pin(num='AT29',name='SPI_MOSI',func=pin_types.BIDIR,unit=6),
            Pin(num='AT30',name='USB2_D4/EC2_TXD0',func=pin_types.BIDIR,unit=6),
            Pin(num='AT31',name='USB2_D7/EC2_TXD3',func=pin_types.BIDIR,unit=6),
            Pin(num='AT32',name='USB2_D0/EC2_RXD0',func=pin_types.BIDIR,unit=6),
            Pin(num='AT33',name='USB2_DIR/EC2_RX_CLK',func=pin_types.INPUT,unit=6),
            Pin(num='AT34',name='USB1_D6/EC1_TXD2',func=pin_types.BIDIR,unit=6),
            Pin(num='AT35',name='USB1_D4/EC1_TXD0',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ30',name='EMI2_MDIO',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='EC_XTRNL_TX_STMP2',func=pin_types.INPUT,unit=7),
            Pin(num='AJ33',name='EMI1_MDC',func=pin_types.OUTPUT,unit=7),
            Pin(num='AK30',name='EMI2_MDC',func=pin_types.OUTPUT,unit=7),
            Pin(num='AK31',name='EC_XTRNL_RX_STMP2',func=pin_types.INPUT,unit=7),
            Pin(num='AK32',name='EC_XTRNL_RX_STMP1',func=pin_types.INPUT,unit=7),
            Pin(num='AK34',name='EC_GTX_CLK125',func=pin_types.INPUT,unit=7),
            Pin(num='AL32',name='EMI1_MDIO',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='EC_XTRNL_TX_STMP1',func=pin_types.INPUT,unit=7),
            Pin(num='AM33',name='EC1_RXD3/USB1_D3',func=pin_types.INPUT,unit=7),
            Pin(num='AM34',name='EC1_RX_DV/USB1_NXT',func=pin_types.INPUT,unit=7),
            Pin(num='AM36',name='EC1_RX_CLK/USB1_DIR',func=pin_types.INPUT,unit=7),
            Pin(num='AN31',name='EC2_GTX_CLK/USB2_CLK',func=pin_types.OUTPUT,unit=7),
            Pin(num='AN32',name='EC2_RXD2/USB2_D2',func=pin_types.INPUT,unit=7),
            Pin(num='AN34',name='EC1_RXD2/USB1_D2',func=pin_types.INPUT,unit=7),
            Pin(num='AN35',name='EC1_RXD1/USB1_D1',func=pin_types.INPUT,unit=7),
            Pin(num='AN36',name='EC1_RXD0/USB1_D0',func=pin_types.INPUT,unit=7),
            Pin(num='AP30',name='EC2_TXD2/USB2_D6',func=pin_types.OUTPUT,unit=7),
            Pin(num='AP32',name='EC2_RXD1/USB2_D1',func=pin_types.INPUT,unit=7),
            Pin(num='AP33',name='EC2_RXD3/USB2_D3',func=pin_types.INPUT,unit=7),
            Pin(num='AP35',name='EC1_GTX_CLK/USB1_CLK',func=pin_types.OUTPUT,unit=7),
            Pin(num='AP36',name='EC1_TXD3/USB1_D7',func=pin_types.BIDIR,unit=7),
            Pin(num='AR30',name='EC2_TXD1/USB2_D5',func=pin_types.OUTPUT,unit=7),
            Pin(num='AR31',name='EC2_TX_EN/USB2_STP',func=pin_types.OUTPUT,unit=7),
            Pin(num='AR33',name='EC2_RX_DV/USB2_NXT',func=pin_types.INPUT,unit=7),
            Pin(num='AR34',name='EC1_TXD1/USB1_D5',func=pin_types.OUTPUT,unit=7),
            Pin(num='AR36',name='EC1_TX_EN/USB1_STP',func=pin_types.OUTPUT,unit=7),
            Pin(num='AT30',name='EC2_TXD0/USB2_D4',func=pin_types.OUTPUT,unit=7),
            Pin(num='AT31',name='EC2_TXD3/USB2_D7',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='EC2_RXD0/USB2_D0',func=pin_types.INPUT,unit=7),
            Pin(num='AT33',name='EC2_RX_CLK/USB2_DIR',func=pin_types.INPUT,unit=7),
            Pin(num='AT34',name='EC1_TXD2/USB1_D6',func=pin_types.OUTPUT,unit=7),
            Pin(num='AT35',name='EC1_TXD0/USB1_D4',func=pin_types.OUTPUT,unit=7),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH34',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ32',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK28',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK34',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AL29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AL34',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AL7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AM11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AM17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AM21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AM32',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AN15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AN3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AN30',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AN9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AP19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AP7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AR16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AR18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AR32',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AR5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AT22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AT36',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y27',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A19',name='AVDD_DDR',func=pin_types.PWRIN,unit=9),
            Pin(num='A20',name='AVDD_CC1',func=pin_types.PWRIN,unit=9),
            Pin(num='A21',name='AVDD_CC2',func=pin_types.PWRIN,unit=9),
            Pin(num='AA6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AB10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AB4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AC2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AC8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AD6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AE10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AE4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AF11',name='SENSEVDD_PL1',func=pin_types.PWRIN,unit=9),
            Pin(num='AF12',name='SENSEGND_PL1',func=pin_types.PWRIN,unit=9),
            Pin(num='AF2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AF8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AG15',name='SENSEVDD_CB',func=pin_types.PWRIN,unit=9),
            Pin(num='AG16',name='SENSEGND_CB',func=pin_types.PWRIN,unit=9),
            Pin(num='AG21',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AG6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AH10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AH4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ12',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ14',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ18',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ23',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ29',name='CVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ35',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AK10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AK33',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AK6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AL10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AL16',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AL20',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AL31',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AL4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AM2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AM35',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AM8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AN12',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AN18',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AN22',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AN33',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AN6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AP10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AP16',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AP29',name='CVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AP31',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AP4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AR14',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AR2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AR24',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AR35',name='LVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AR8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AT15',name='OVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AT17',name='POVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AT18',name='AVDD_CC3',func=pin_types.PWRIN,unit=9),
            Pin(num='AT19',name='AVDD_CC4',func=pin_types.PWRIN,unit=9),
            Pin(num='AT20',name='AVDD_PLAT',func=pin_types.PWRIN,unit=9),
            Pin(num='B14',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='B19',name='MVREF',func=pin_types.INPUT,unit=9),
            Pin(num='B2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='B24',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='B8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='C12',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='C18',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='C6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='D10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='D16',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='D4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='E14',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='E2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='E22',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='E24',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='E8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='F12',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='F20',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='F26',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='F6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='G10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='G16',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='G4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='H14',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='H18',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='H2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='H20',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='H8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='J12',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='J6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='K10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='K16',name='SENSEVDD_CA',func=pin_types.PWRIN,unit=9),
            Pin(num='K17',name='SENSEGND_CA',func=pin_types.PWRIN,unit=9),
            Pin(num='K22',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='K24',name='BVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='K27',name='SENSEGND_PL2',func=pin_types.PWRIN,unit=9),
            Pin(num='K4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='L2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='L27',name='SENSEVDD_PL2',func=pin_types.PWRIN,unit=9),
            Pin(num='L8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='M6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='N10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='N4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='P2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='P8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='R6',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='T10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='T4',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='U2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='U8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='V7',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='W10',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='Y2',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='Y8',name='GVDD',func=pin_types.PWRIN,unit=9),
            Pin(num='AA11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AA13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AA15',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AA17',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AA19',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AA21',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AA23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AA25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AA27',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AB12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AB14',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AB16',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AB18',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AB20',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AB22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AB24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AB26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC15',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AC17',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AC19',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='AC21',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AC27',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD16',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD18',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD20',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AD26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE15',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE17',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE19',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE21',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AE25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF16',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF18',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF20',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='AF24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L15',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L17',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L19',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L21',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='L25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='M12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='M14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='M16',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='M18',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='M20',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='M22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='M24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='M26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='N11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='N13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='N15',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='N17',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='N19',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='N21',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='N23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='N25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='N27',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='P12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='P14',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='P16',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='P18',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='P20',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='P22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='P24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='P26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='R11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='R13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='R15',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='R17',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='R19',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='R21',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='R23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='R25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='R27',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='T12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='T14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='T16',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='T18',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='T20',name='VDD_CA',func=pin_types.PWRIN,unit=10),
            Pin(num='T22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='T24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='T26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U15',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U17',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U19',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U21',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='U27',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V16',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V18',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V20',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='V26',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W11',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W13',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W15',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='W17',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='W19',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='W21',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W23',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W25',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='W28',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='Y12',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='Y14',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='Y16',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='Y18',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='Y20',name='VDD_CB',func=pin_types.PWRIN,unit=10),
            Pin(num='Y22',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='Y24',name='VDD_PL',func=pin_types.PWRIN,unit=10),
            Pin(num='Y26',name='VDD_PL',func=pin_types.PWRIN,unit=10)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AR13', 'F11', 'N8', 'AF7', 'AR9', 'N9', 'F13', 'AF9', 'AT10', 'F14', 'P10', 'AG10', 'AT11', 'P6', 'F16', 'AG5', 'AT12', 'F2', 'P7', 'AG7', 'AT13', 'F7', 'P9', 'A16', 'AG8', 'AT9', 'F8', 'R10', 'AH5', 'B15', 'G11', 'R7', 'AA5', 'AH6', 'B16', 'G12', 'R8', 'AH8', 'B17', 'G14', 'T6', 'AH9', 'C10', 'G15', 'T8', 'AJ10', 'C11', 'G8', 'T9', 'AA7', 'AJ6', 'C14', 'G9', 'U10', 'A15', 'AA10', 'AA8', 'AJ7', 'C16', 'H10', 'U6', 'C17', 'AB5', 'AJ9', 'AB6', 'H7', 'U7', 'AK7', 'C8', 'U9', 'H9', 'AB8', 'AK8', 'D11', 'J10', 'V5', 'AB9', 'AL1', 'D12', 'J5', 'V6', 'AC10', 'AL11', 'D14', 'A17', 'J7', 'V8', 'AC6', 'AL2', 'D15', 'J8', 'V9', 'AC7', 'AL8', 'D17', 'K5', 'W5', 'AC9', 'AL9', 'D8', 'K6', 'W6', 'AD10', 'AM10', 'D9', 'K8', 'W8', 'AD4', 'AM9', 'E10', 'K9', 'W9', 'AD5', 'AN10', 'E12', 'L10', 'Y10', 'AD7', 'AN11', 'E13', 'L6', 'Y7', 'AD8', 'AN7', 'E15', 'L7', 'Y9', 'AE5', 'AN8', 'E6', 'L9', 'AE6', 'AP12', 'E7', 'M10', 'AE8', 'AP9', 'E9', 'M7', 'AE9', 'AF6', 'AR10', 'F1', 'A14', 'M8', 'AF10', 'AR12', 'F10', 'N6']},{'label': 'uB', 'num': 2, 'pin_nums': ['L3', 'AN2', 'AC3', 'C13', 'L4', 'Y6', 'AN4', 'AC4', 'C2', 'M1', 'AD1', 'AN5', 'C4', 'M2', 'AP1', 'AD2', 'C5', 'M4', 'AE1', 'AP2', 'C7', 'M5', 'AA2', 'AE2', 'AP3', 'A11', 'D1', 'N1', 'AE3', 'AP5', 'D2', 'N2', 'AF1', 'AP6', 'D3', 'N3', 'AF3', 'AP8', 'D5', 'N5', 'A9', 'A6', 'AF4', 'AR1', 'D6', 'P1', 'AG1', 'AR3', 'E1', 'P3', 'A13', 'AR4', 'AG2', 'E3', 'P4', 'AA1', 'A7', 'AG4', 'AR6', 'E4', 'R1', 'A5', 'AH1', 'AR7', 'F4', 'R2', 'A4', 'A8', 'A3', 'AH2', 'AT1', 'F5', 'R4', 'A2', 'AH3', 'AT2', 'G1', 'R5', 'AJ1', 'AT3', 'AA4', 'G2', 'T1', 'AJ3', 'AT4', 'G3', 'T2', 'AJ4', 'AT5', 'A12', 'G5', 'T3', 'AT6', 'AK1', 'G6', 'T5', 'AK2', 'AT7', 'H1', 'U1', 'AK4', 'AT8', 'H3', 'U4', 'AK5', 'B1', 'H4', 'V1', 'AL3', 'B10', 'H6', 'V2', 'AL5', 'B12', 'J1', 'V3', 'AL6', 'B13', 'J2', 'V4', 'AM1', 'B3', 'J4', 'W1', 'A10', 'AM3', 'B4', 'AB1', 'K1', 'W2', 'AN1', 'AA3', 'AM4', 'B6', 'K2', 'W3', 'AB2', 'AM6', 'B7', 'K3', 'W4', 'Y4', 'AB3', 'AM7', 'B9', 'L1', 'Y1', 'AC1', 'C1']},{'label': 'uC', 'num': 3, 'pin_nums': ['AM13', 'F22', 'AM14', 'F24', 'A23', 'AM20', 'F25', 'A24', 'AM22', 'G18', 'AG13', 'AN19', 'G19', 'AG17', 'AN20', 'G20', 'AG19', 'AN21', 'G22', 'AG20', 'AN23', 'G23', 'AH14', 'AP20', 'G24', 'AH16', 'AP21', 'G25', 'AH17', 'AP22', 'G26', 'AH21', 'AR23', 'H19', 'AH23', 'B23', 'H21', 'AJ13', 'B25', 'H22', 'AJ15', 'C22', 'H23', 'AJ16', 'C23', 'H24', 'AJ20', 'C24', 'H25', 'AJ21', 'C25', 'H26', 'AJ22', 'D19', 'J17', 'AJ34', 'D20', 'J18', 'AK11', 'D21', 'J19', 'AK12', 'D22', 'J20', 'AK13', 'D23', 'J22', 'AK14', 'D24', 'J24', 'AK21', 'D25', 'J25', 'AK22', 'E20', 'J26', 'AK23', 'E21', 'K18', 'AK35', 'E23', 'K20', 'AL12', 'E25', 'K21', 'AL19', 'E26', 'K23', 'AL21', 'F19', 'K26', 'AL22', 'F21', 'L26']},{'label': 'uD', 'num': 4, 'pin_nums': ['P36', 'A29', 'E31', 'T30', 'A31', 'E34', 'T31', 'A35', 'F29', 'T33', 'AA31', 'F31', 'T34', 'AA32', 'F33', 'V33', 'AA35', 'F35', 'V34', 'AA36', 'F36', 'W31', 'AB33', 'G28', 'W32', 'AB34', 'G30', 'W35', 'AC31', 'G33', 'W36', 'AC32', 'H28', 'Y29', 'AC35', 'H30', 'Y30', 'AC36', 'H35', 'Y33', 'AE31', 'H36', 'Y34', 'AE32', 'J33', 'AF33', 'J34', 'AF34', 'K31', 'AG31', 'K32', 'AG32', 'K35', 'AG35', 'K36', 'AG36', 'L33', 'B29', 'L34', 'B31', 'M31', 'B35', 'M32', 'C28', 'M35', 'C30', 'M36', 'C36', 'N33', 'D28', 'N34', 'D30', 'P31', 'D34', 'P32', 'D36', 'P35', 'E29']},{'label': 'uE', 'num': 5, 'pin_nums': ['AC34', 'C31', 'R32', 'J31', 'C33', 'AD30', 'R33', 'J32', 'AD31', 'C34', 'J35', 'R34', 'C35', 'AD32', 'R35', 'J36', 'D29', 'AD35', 'K28', 'R36', 'AD36', 'D31', 'K29', 'T29', 'AE30', 'D33', 'K30', 'T32', 'AE33', 'D35', 'T35', 'K33', 'AE34', 'E28', 'K34', 'T36', 'AE35', 'E30', 'L29', 'U29', 'AE36', 'E32', 'L30', 'U30', 'AF30', 'E33', 'L31', 'U31', 'AF31', 'E35', 'L32', 'U33', 'AF32', 'E36', 'L35', 'U34', 'AF35', 'F28', 'L36', 'U36', 'A28', 'AF36', 'F30', 'M29', 'V29', 'A30', 'AG30', 'F32', 'M30', 'V30', 'A32', 'AG33', 'F34', 'M33', 'V31', 'A33', 'AG34', 'G29', 'M34', 'V32', 'A34', 'AH31', 'G31', 'N29', 'V35', 'A36', 'AH32', 'G32', 'N30', 'V36', 'C29', 'AA29', 'AH33', 'G34', 'N31', 'W29', 'AA30', 'AH35', 'G35', 'N32', 'W30', 'AA33', 'AH36', 'G36', 'N35', 'W33', 'AA34', 'B27', 'H29', 'N36', 'W34', 'AB30', 'B28', 'H31', 'P29', 'Y31', 'AB31', 'B30', 'H32', 'P30', 'Y32', 'AB32', 'B32', 'H33', 'P33', 'Y35', 'AB35', 'B33', 'H34', 'P34', 'Y36', 'AB36', 'B34', 'J28', 'R29', 'AC30', 'B36', 'J29', 'R30', 'AC33', 'J30', 'R31']},{'label': 'uF', 'num': 6, 'pin_nums': ['AG22', 'AL35', 'AP32', 'AL36', 'AG23', 'AP33', 'AH15', 'AM14', 'AP35', 'AM15', 'AH18', 'AP36', 'AH19', 'AM16', 'AR15', 'AH20', 'AM18', 'AR17', 'AH23', 'AM19', 'AR19', 'AH28', 'AM22', 'AR20', 'AJ17', 'AM23', 'AR21', 'AJ19', 'AM29', 'AR22', 'AJ20', 'AM30', 'AR23', 'AJ22', 'AM33', 'AR29', 'AJ28', 'AM34', 'AR30', 'AJ34', 'AM36', 'AR31', 'AJ36', 'AN14', 'AR33', 'AK13', 'AN16', 'AR34', 'AK14', 'AN17', 'AR36', 'AK16', 'AN23', 'AT16', 'AK17', 'AN24', 'AT21', 'AK18', 'AN29', 'AT23', 'AK20', 'AN31', 'AT24', 'AK23', 'AN32', 'AT29', 'AK29', 'AN34', 'AT30', 'AK35', 'AN35', 'AT31', 'AK36', 'AN36', 'AT32', 'AL14', 'AP15', 'AT33', 'AL15', 'AP17', 'AT34', 'AL17', 'AP18', 'AT35', 'AL18', 'AP20', 'AL22', 'AP22', 'AG14', 'AP24', 'AL23', 'AG19', 'AL30', 'AP30']},{'label': 'uG', 'num': 7, 'pin_nums': ['AK30', 'AM36', 'AP33', 'AT30', 'AK31', 'AN31', 'AP35', 'AT31', 'AK32', 'AN32', 'AP36', 'AT32', 'AK34', 'AN34', 'AR30', 'AT33', 'AR31', 'AL32', 'AN35', 'AT34', 'AJ30', 'AM31', 'AN36', 'AR33', 'AT35', 'AJ31', 'AM33', 'AP30', 'AR34', 'AJ33', 'AM34', 'AP32', 'AR36']},{'label': 'uH', 'num': 8, 'pin_nums': ['P11', 'Y21', 'AD17', 'A26', 'AH7', 'AR5', 'K19', 'P13', 'U18', 'Y23', 'AD19', 'AA12', 'AT22', 'AJ11', 'K25', 'P15', 'U20', 'Y25', 'AA14', 'AD21', 'AJ32', 'AT36', 'K7', 'P17', 'U22', 'Y27', 'AA16', 'AD23', 'AJ5', 'B11', 'L12', 'P19', 'U24', 'Y3', 'AA18', 'AD25', 'AK15', 'B18', 'L14', 'P21', 'U26', 'Y5', 'AA20', 'AD27', 'AK19', 'B20', 'L16', 'P23', 'U3', 'AA22', 'AD3', 'AK28', 'B22', 'L18', 'P25', 'U5', 'AA24', 'AD9', 'B5', 'AK3', 'L20', 'P27', 'V10', 'AA26', 'AE12', 'AK34', 'C15', 'L22', 'P5', 'V11', 'AA9', 'AE14', 'AK9', 'C3', 'L24', 'R12', 'V13', 'AB11', 'AE16', 'AL13', 'C9', 'AD15', 'L5', 'R14', 'V15', 'AB13', 'AE18', 'AL29', 'D13', 'M11', 'R16', 'V17', 'AB15', 'AE20', 'AL34', 'D7', 'M13', 'R18', 'V19', 'AB17', 'AE22', 'AL7', 'E11', 'M15', 'R20', 'V21', 'AB19', 'AE24', 'AM11', 'E17', 'M17', 'R22', 'V23', 'AB21', 'AE26', 'AM17', 'E19', 'M19', 'R24', 'V25', 'AB23', 'AE27', 'AM21', 'E5', 'M21', 'R26', 'V27', 'AB25', 'AE7', 'AM32', 'F15', 'M23', 'R3', 'AR32', 'W12', 'AB27', 'AF13', 'AM5', 'F23', 'M25', 'R9', 'W14', 'AB7', 'AF15', 'AN15', 'F27', 'M27', 'T11', 'W16', 'AC12', 'AF17', 'AN3', 'F3', 'M3', 'T13', 'W18', 'AC14', 'AF19', 'AN30', 'F9', 'M9', 'T15', 'W20', 'AC16', 'AF21', 'AN9', 'G13', 'N12', 'T17', 'W22', 'AC18', 'AF23', 'AP13', 'G21', 'N14', 'T19', 'W24', 'AC20', 'AF25', 'AP19', 'G7', 'N16', 'T21', 'W26', 'AC22', 'AF5', 'AP23', 'H11', 'N18', 'T23', 'W7', 'AC24', 'AG18', 'AP34', 'H5', 'N20', 'T25', 'Y11', 'AC26', 'AG3', 'AP7', 'J21', 'N22', 'T27', 'Y13', 'AC5', 'AG9', 'AR11', 'J23', 'N24', 'T7', 'Y15', 'AD11', 'AH13', 'AR16', 'J27', 'N26', 'U12', 'A18', 'U16', 'Y17', 'AD13', 'AH22', 'AR18', 'J3', 'N7', 'U14', 'A22', 'Y19', 'AH34', 'J9']},{'label': 'uI', 'num': 9, 'pin_nums': ['AT19', 'AJ29', 'K10', 'AT20', 'AJ35', 'K16', 'AT18', 'AJ8', 'B14', 'K17', 'B19', 'AK10', 'K22', 'AK33', 'B2', 'K24', 'B24', 'AK6', 'K27', 'A19', 'AL10', 'B8', 'K4', 'A20', 'AL16', 'C12', 'L2', 'A21', 'AL20', 'C18', 'L27', 'AA6', 'AL31', 'C6', 'L8', 'AB10', 'AL4', 'D10', 'M6', 'AB4', 'AM2', 'D16', 'N10', 'AC2', 'AM35', 'D4', 'N4', 'AC8', 'AM8', 'E14', 'P2', 'AD6', 'AN12', 'E2', 'P8', 'AE10', 'AN18', 'E22', 'R6', 'AE4', 'AN22', 'E24', 'T10', 'AF11', 'AN33', 'E8', 'T4', 'AF12', 'AN6', 'F12', 'U2', 'AF2', 'AP10', 'F20', 'U8', 'AF8', 'AP16', 'F26', 'V7', 'AG15', 'AP29', 'F6', 'W10', 'AG16', 'AP31', 'G10', 'Y2', 'AG21', 'AP4', 'G16', 'Y8', 'AG6', 'AR14', 'G4', 'AH10', 'AR2', 'H14', 'AH4', 'AR24', 'H18', 'AJ12', 'AR35', 'H2', 'AJ14', 'AR8', 'H20', 'AJ18', 'AT15', 'H8', 'AJ2', 'AT17', 'J12', 'AJ23', 'J6']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AA25', 'N25', 'U21', 'AA27', 'AE23', 'N27', 'U23', 'AB12', 'AE25', 'P12', 'U25', 'AB14', 'AF14', 'P14', 'U27', 'AB16', 'AF16', 'P16', 'V12', 'AB18', 'AF18', 'P18', 'V14', 'AB20', 'AF20', 'P20', 'V16', 'AB22', 'AF22', 'P22', 'V18', 'AB24', 'AF24', 'P24', 'V20', 'AB26', 'L11', 'P26', 'V22', 'AC11', 'L13', 'R11', 'V24', 'AC13', 'L15', 'R13', 'V26', 'AC15', 'L17', 'R15', 'W11', 'AC17', 'L19', 'R17', 'W13', 'AC19', 'L21', 'R19', 'W15', 'AC21', 'L23', 'R21', 'W17', 'AC23', 'L25', 'R23', 'W19', 'AC25', 'M12', 'R25', 'W21', 'AC27', 'M14', 'R27', 'W23', 'AD12', 'M16', 'T12', 'W25', 'AD14', 'M18', 'T14', 'W28', 'AD16', 'M20', 'T16', 'Y12', 'AD18', 'M22', 'T18', 'Y14', 'AD20', 'M24', 'T20', 'Y16', 'AD22', 'M26', 'T22', 'Y18', 'AA11', 'AD24', 'N11', 'T24', 'Y20', 'AA13', 'AD26', 'N13', 'T26', 'Y22', 'AA15', 'AE11', 'N15', 'U11', 'Y24', 'AA17', 'AE13', 'N17', 'U13', 'Y26', 'AA19', 'AE15', 'N19', 'U15', 'AA21', 'AE17', 'AE21', 'N21', 'U17', 'AA23', 'AE19', 'N23', 'U19']}] }),
        Part(**{ 'name':'Z80CPU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z80CPU'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Z80 CPU uP', 'description':'', 'datasheet':'www.zilog.com/manage_directlink.php?filepath=docs/z80/um0080', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nZ80CPU\n\nZ80 CPU uP', 'pins':[
            Pin(num='1',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{INT}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{HALT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{MREQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{IORQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{RD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{WR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{BUSACK}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{WAIT}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{BUSRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{M1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{RFSH}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CLK}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDP1802ACEX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDP1802ACEX'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'CPU Processor', 'description':'', 'datasheet':'http://www.cosmacelf.com/publications/data-sheets/cdp1802.pdf', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nCDP1802ACEX\n\nCPU Processor', 'pins':[
            Pin(num='1',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='BUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='BUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='BUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='BUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='BUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='N2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='N1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='N0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{WAIT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{EF4}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{EF3}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{EF2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{EF1}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='MA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='MA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='MA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='MA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CLEAR}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='MA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='MA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='TPB',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='TPA',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='~{MWR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{INTERRUPT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DMA_OUT}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{DMA_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{XTAL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{MRD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='BUS6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDP1802BCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDP1802BCE'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'CPU Processor', 'description':'', 'datasheet':'http://www.cosmacelf.com/publications/data-sheets/cdp1802.pdf', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nCDP1802BCE\n\nCPU Processor', 'pins':[
            Pin(num='1',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='BUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='BUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='BUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='BUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='BUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='N2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='N1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='N0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{WAIT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{EF4}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{EF3}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{EF2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{EF1}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='MA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='MA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='MA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='MA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CLEAR}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='MA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='MA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='TPB',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='TPA',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='~{MWR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{INTERRUPT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DMA_OUT}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{DMA_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{XTAL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{MRD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='BUS6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDP1802BCEX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDP1802BCEX'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'CPU Processor', 'description':'', 'datasheet':'http://www.cosmacelf.com/publications/data-sheets/cdp1802.pdf', 'search_text':'/usr/share/kicad/symbols/CPU.kicad_sym\nCDP1802BCEX\n\nCPU Processor', 'pins':[
            Pin(num='1',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='BUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='BUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='BUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='BUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='BUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='N2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='N1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='N0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{WAIT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{EF4}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{EF3}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{EF2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{EF1}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='MA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='MA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='MA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='MA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='MA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CLEAR}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='MA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='MA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='TPB',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='TPA',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='~{MWR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{INTERRUPT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DMA_OUT}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{DMA_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{XTAL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{MRD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='BUS6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])